@@ -46,14 +46,27 @@ BatchGetRecordErrorTypeDef = TypedDict(
     },
 )
 
-BatchGetRecordIdentifierTypeDef = TypedDict(
-    "BatchGetRecordIdentifierTypeDef",
+_RequiredBatchGetRecordIdentifierTypeDef = TypedDict(
+    "_RequiredBatchGetRecordIdentifierTypeDef",
     {
         "FeatureGroupName": str,
         "RecordIdentifiersValueAsString": Sequence[str],
-        "FeatureNames": NotRequired[Sequence[str]],
     },
 )
+_OptionalBatchGetRecordIdentifierTypeDef = TypedDict(
+    "_OptionalBatchGetRecordIdentifierTypeDef",
+    {
+        "FeatureNames": Sequence[str],
+    },
+    total=False,
+)
+
+
+class BatchGetRecordIdentifierTypeDef(
+    _RequiredBatchGetRecordIdentifierTypeDef, _OptionalBatchGetRecordIdentifierTypeDef
+):
+    pass
+
 
 BatchGetRecordRequestRequestTypeDef = TypedDict(
     "BatchGetRecordRequestRequestTypeDef",
@@ -98,14 +111,27 @@ FeatureValueTypeDef = TypedDict(
     },
 )
 
-GetRecordRequestRequestTypeDef = TypedDict(
-    "GetRecordRequestRequestTypeDef",
+_RequiredGetRecordRequestRequestTypeDef = TypedDict(
+    "_RequiredGetRecordRequestRequestTypeDef",
     {
         "FeatureGroupName": str,
         "RecordIdentifierValueAsString": str,
-        "FeatureNames": NotRequired[Sequence[str]],
     },
 )
+_OptionalGetRecordRequestRequestTypeDef = TypedDict(
+    "_OptionalGetRecordRequestRequestTypeDef",
+    {
+        "FeatureNames": Sequence[str],
+    },
+    total=False,
+)
+
+
+class GetRecordRequestRequestTypeDef(
+    _RequiredGetRecordRequestRequestTypeDef, _OptionalGetRecordRequestRequestTypeDef
+):
+    pass
+
 
 GetRecordResponseTypeDef = TypedDict(
     "GetRecordResponseTypeDef",
